#[non_exhaustive]pub struct MetadataException {
pub message: Option<String>,
/* private fields */
}Expand description
An exception that Athena received when it called a custom metastore. Occurs if the error is not caused by user input (InvalidRequestException) or from the Athena platform (InternalServerException). For example, if a user-created Lambda function is missing permissions, the Lambda 4XX exception is returned in a MetadataException.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>Implementations
Sourceimpl MetadataException
impl MetadataException
Sourcepub fn builder() -> MetadataExceptionBuilder
pub fn builder() -> MetadataExceptionBuilder
Creates a new builder-style object to manufacture MetadataException.